package com.xinelu.manage.service.patientvisitouthospital;

import java.util.List;

import com.xinelu.manage.domain.patientvisitouthospital.PatientVisitOutHospital;

/**
 * 患者就诊出院记录信息Service接口
 *
 * @author xinelu
 * @date 2024-02-26
 */
public interface IPatientVisitOutHospitalService {
    /**
     * 查询患者就诊出院记录信息
     *
     * @param id 患者就诊出院记录信息主键
     * @return 患者就诊出院记录信息
     */
    public PatientVisitOutHospital selectPatientVisitOutHospitalById(Long id);

    /**
     * 查询患者就诊出院记录信息列表
     *
     * @param patientVisitOutHospital 患者就诊出院记录信息
     * @return 患者就诊出院记录信息集合
     */
    public List<PatientVisitOutHospital> selectPatientVisitOutHospitalList(PatientVisitOutHospital patientVisitOutHospital);

	PatientVisitOutHospital getByVisitRecord(Long patientVisitRecordId);

    /**
     * 新增患者就诊出院记录信息
     *
     * @param patientVisitOutHospital 患者就诊出院记录信息
     * @return 结果
     */
    public int insertPatientVisitOutHospital(PatientVisitOutHospital patientVisitOutHospital);

    /**
     * 修改患者就诊出院记录信息
     *
     * @param patientVisitOutHospital 患者就诊出院记录信息
     * @return 结果
     */
    public int updatePatientVisitOutHospital(PatientVisitOutHospital patientVisitOutHospital);

    /**
     * 批量删除患者就诊出院记录信息
     *
     * @param ids 需要删除的患者就诊出院记录信息主键集合
     * @return 结果
     */
    public int deletePatientVisitOutHospitalByIds(Long[] ids);

    /**
     * 删除患者就诊出院记录信息信息
     *
     * @param id 患者就诊出院记录信息主键
     * @return 结果
     */
    public int deletePatientVisitOutHospitalById(Long id);
}
